Francisco Goya: Painting of Woman Mini Art Print > Mini Posters > Famous Art Science Quotes Poster T-Shirt Gift Shop
Description: Famous Art Science Quotes Poster T-Shirt Gift Shop: Francisco Goya: Painting of Woman Mini Art Print:
Keywords: Philosophy, Shop, Gift, Idea, Artist, Images, Products, Ancient, Greek, Indian, Chinese, Western, Education, Religion, Life, Science, Quote, Fine, Art, Prints, Posters, Calendars, Cards, Journals, Clothes, Men's, Women's, Clothing, T-Shirts, Apparel

- Cart & Checkout
- Help
- Order Status
- Shop Home
- Currency:

Comment with Facebook Connect
Google Friend
Twitter / Tweet
@Philosophy_Shop
Share |
### Products
Large Posters Small Posters Mini Poster Prints Framed Poster Panel Prints 2010 Wall Calendars Journals / Diaries Postcards Greeting Cards Mousepads Bumper Stickers Coffee Cups, Mugs & Beer Steins Wall / Time Clocks Buttons / Badges Fridge Magnets Jewelry Box & Coasters Unique Custom Printed Tees Men's Women's White T-Shirts Men's Women's Black T-Shirts Longsleeve T Shirts Hooded Sweatshirts Women's Long Sleeve Clothing Tight Sexy Ladies Clothes Men's & Women's Boxer Shorts Women's Intimate Lingerie, Erotic Thongs Cotton Canvas Printed Tote Bag & Messenger Bags Children / Infant / Kids Clothes Printed Kitchen Chef BBQ Cooking Aprons Baseball Caps & Trucker Hats Dog Clothes

### Subjects
Ancient Greek Philosophy
Chinese Indian Metaphysics
Western Philosophy
20th Century Philosophers
Physics & Science Quotes
Scientists & Inventors
Famous Mathematicians
God Religion Morality
Famous Leader Politics
Education Educational
Evolution Life Nature
Motivational Inspirational
Metaphysical Poets
Literature Books Authors
Musicians Composers
Women Feminism Art
Renaissance Fine Art
Satire Humor Funny Jokes
Philosophy Shop Philosophy Website
Newsletter

The Philosophy Gift Shop
'The Gift of Truth Excels all Other Gifts' (Buddha)
Hello and welcome to the Philosophy Shop. We have a beautiful gallery of famous portraits and fine art prints with profound quotes from many of the greatest minds of human history - making it simple and easy to find artful intelligent gifts for friends and family (and yourself of course!).
We have purchased a variety of things (posters, journals, calendars, caps, t-shirts, buttons, coffee mugs, etc.) and can confirm their high quality. But most importantly, the daily experience of seeing these portraits and words of wisdom is a cheerful reminder of the more noble and beautiful aspects of our human nature & creativity.
So stand out from the crowd (and get some interesting comments!) with our cool collection of clothing, prints and apparel!
Hope you enjoy browsing around. Cheers,
Karene Jade Howie

View larger
| # Francisco Goya: Painting of Woman Mini Art Print "Feminism is the radical notion that women are people." (Cheris Kramerae, author of A Feminist Dictionary, 1996, printed on Goya Portrait of a Woman) Mini Art Poster $9.99
Qty: |
AVAILABILITY: Product Number: 030-39196067 Share | Product Information Like a poster -- only smaller! Our high quality one page prints are printed on glossy, 12 point paper and measure 11" x 17". Full bleed dynamic color Glossy, 12 point paper IMPORTED

#### Browse more products:

Drag the square at the left to choose the part of your image you want to use. Tips: Click and drag any corner to resize; click and drag from the inside to move.

### Crop Preview:

Click done if you're happy with the way it looks.

Facebook Connect

Google Friend Connect

Twitter
@Philosophy_Shop

### Philosophy Shop Tweets

### About Cafepress: Website Details / Customer Service & Help

ABOUT CAFEPRESS: Cafepress are a print on demand online shop. As of November 2009 there are over 6 million members (shopkeepers who create their own shops & products) and 40 million products! The website is in the top 1000 websites on the internet and gets around one million visitors each day. Because products are print on demand they are more expensive than mass produced goods, however, you have the advantage of purchasing unique custom made products that are not found anywhere else (this is particularly true for our philosophy shop). Cafepress ships products world wide (we live in Australia and have bought numerous items without any problems) and they have a thirty day full refund so it is a safe place to purchase some pretty cool gifts / presents (for yourself or others!).

Order by Phone 1-877-809-1659 (30 Day Refund - Satisfaction Guaranteed)

CUSTOMER SERVICE: For help with: Cafepress Sales - Where's My Stuff - Track your Recent Orders - View or Change your Order - Shipping and Returns - Shipping Rates - Make a Return or Exchange - Questions and Order by Phone 1-877-809-1659 - Satisfaction Guaranteed.

Philosophy Shop: Famous Portraits and Quotes on Posters, Tshirts, Clothing, Apparel. is UpFront

ABOUT YOUR SHOP KEEPER: KARENE HOWIE My partner (philosopher Geoff Haselhurst) and I are building a large philosophy website which is the source (and inspiration) for most of the Philosophy images and quotes in this shop. Below are some of our favourite philosophers / quotes and links to relevant pages of our website. Philosophy (which is ultimately about Wisdom from Truth and Reality) is important to our world (all proceeds from this shop are used to promote our work on Philosophy). Thus we also hope that you find our philosophy website interesting! Cheers, Karene. (August, 2010)

The Most Simple Science Theory of Physical Reality.
Philosophy Physics Metaphysics of Space & the Wave Structure of Matter (WSM).

Simple Science | Metaphysics Reality | Einstein's Relativity | Quantum Physics | Cosmology Universe | Philosophy Truth | Evolution Utopia | Theology Morality | Philosophy Sexuality | Human Health Nutrition Diet

### Copyright 2005 - 2010: All Rights Reserved
The Philosophy Shop averages around 2,500 visitors each day (6,000 page views). We are one of the Top Shops at Cafepress (out of about 6 million shops).

This shop is powered by CafePress Inc. Copyright © 1999-
CafePress.com. All rights reserved.
Privacy Policy | Trademark & Copyright Information
Non-US currency rates are updated daily and may fluctuate.

{"SumOfAllMeasurementsBelowReportingThreshold":23}